package fr.itsee.zelyx;

import static java.lang.Double.parseDouble;
import static java.lang.Integer.parseInt;

import android.content.Context;
import android.graphics.Color;
import android.graphics.Typeface;
import android.graphics.drawable.Drawable;
import android.os.AsyncTask;
import android.os.StrictMode;
import android.support.v7.widget.RecyclerView;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.Filter;
import android.widget.Filterable;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.squareup.picasso.Picasso;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class ClientAdapter extends RecyclerView.Adapter<ClientAdapter.MyViewHolder> implements Filterable {
//    public class ClientAdapter extends RecyclerView.Adapter<fr.itsee.zelyx.ClientAdapter.MyViewHolder> {

    public static List<Client> listeAllClients;
    public static List<Client> listeAllClientsFiltered;

    private OnItemClickListener mListener;
    private Context context;

    public ClientAdapter(Context context) {
        this.context = context;
    }

    @Override
    //Rechercher dans la recyclerview
    public Filter getFilter() {
        return new Filter() {
            @Override
            protected FilterResults performFiltering(CharSequence charSequence) {
                String charString = charSequence.toString();
                if (charString.isEmpty()) {
                    listeAllClientsFiltered = listeAllClients;
                } else {
                    List<Client> filteredList = new ArrayList<>();
                    for (Client row : listeAllClientsFiltered) {
                        if (row.getNomEntreprise().contains(charString.toLowerCase()) || row.getSiren().contains(charSequence) || row.getTelephone().contains(charSequence) || row.getTelephone2().contains(charSequence) || row.getNom().contains(charSequence)) {
                            filteredList.add(row);
                        }
                    }
                    listeAllClientsFiltered = filteredList;
                }

                FilterResults filterResults = new FilterResults();
                filterResults.values = listeAllClientsFiltered;
                return filterResults;
            }

            @Override
            protected void publishResults(CharSequence charSequence, FilterResults filterResults) {
                listeAllClientsFiltered = (ArrayList<Client>) filterResults.values;
                notifyDataSetChanged();
            }
        };
    }

    public void setOnItemClickListener(OnItemClickListener listener) {
        mListener = listener;
    }

    @Override
    public MyViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View itemView = LayoutInflater.from(parent.getContext())
                .inflate(R.layout.ligne_client, parent, false);
        return new MyViewHolder(itemView, mListener);
    }

    @Override
    public void onBindViewHolder(final MyViewHolder holder, final int position) {
        final Client c = CommandesActivity.listeAllClientsFiltre.get(position);

        /*if (c.getId() == CommandesActivity.currentCommande.getIdClient()) {
            holder.choisir.setBackgroundResource(R.color.colorNoir);
            holder.choisir.setText("CHOISI");
        } else {
            holder.choisir.setBackgroundResource(R.color.colorCommande);
            holder.choisir.setText("CHOISIR");
        }*/

        if (c.getNomEntreprise() != null) {
            holder.nom_entreprise.setText(c.getNomEntreprise());
        } else {
            holder.nom_entreprise.setText("");
        }
        if (c.getSiren() != null) {
            holder.siren.setText(c.getSiren());
        } else {
            holder.siren.setText("");
        }
        if (c.getNom() != null && c.getPrenom() != null) {
            holder.nom_prenom.setText(c.getNom() + " " + c.getPrenom());
        } else if (c.getNom() != null) {
            holder.nom_prenom.setText(c.getNom());
        } else if (c.getPrenom() != null) {
            holder.nom_prenom.setText(c.getPrenom());
        } else {
            holder.nom_prenom.setText("");
        }
        if (c.getTelephone2() != null && c.getTelephone() != null) {
            holder.telephone.setText(c.getTelephone()+" / "+c.getTelephone2());
        } else if (c.getTelephone2() != null) {
            holder.telephone.setText(c.getTelephone2());
        } else if (c.getTelephone() != null) {
            holder.telephone.setText(c.getTelephone());
        } else {
            holder.telephone.setText("");
        }
        if (c.getAdresse() != null && c.getAdresse2() != null) {
            holder.adresse.setText(c.getAdresse() + ' ' + c.getAdresse2());
        } else if (c.getAdresse() != null) {
            holder.adresse.setText(c.getAdresse());
        } else if (c.getAdresse2() != null) {
            holder.adresse.setText(c.getAdresse2());
        }
        if (c.getVille() != null && c.getCp() != null) {
            holder.cp_ville.setText(c.getCp() + ' ' + c.getVille());
        } else if (c.getVille() != "") {
            holder.cp_ville.setText(c.getVille());
        } else {
            holder.cp_ville.setText("");
        }
        if (c.getPays() != "") {
            holder.pays.setText(c.getPays());
        } else {
            holder.pays.setText("");
        }
    }

    @Override
    public int getItemCount() {
        if (CommandesActivity.listeAllClientsFiltre != null) {
            return CommandesActivity.listeAllClientsFiltre.size(); //return cmd.getListeClients().size();
        } else {
            return 0;
        }
    }

    public interface OnItemClickListener {
        void onChoisirClick(int position);
    }

    public class MyViewHolder extends RecyclerView.ViewHolder {
        public TextView nom_entreprise, siren, nom_prenom, telephone, adresse, cp_ville, pays;
        public LinearLayout ligneClient;
        private Button choisir;

        public MyViewHolder(View view, final OnItemClickListener listener) {
            super(view);

            StrictMode.ThreadPolicy policy = new StrictMode.ThreadPolicy.Builder().permitAll().build();
            StrictMode.setThreadPolicy(policy);

            nom_entreprise = view.findViewById(R.id.nom_entreprise);
            siren = view.findViewById(R.id.siren);
            nom_prenom = view.findViewById(R.id.nom_prenom);
            telephone = view.findViewById(R.id.telephone);
            adresse = view.findViewById(R.id.adresse);
            cp_ville = view.findViewById(R.id.cp_ville);
            pays = view.findViewById(R.id.pays);
            choisir = view.findViewById(R.id.choisir);
            ligneClient = view.findViewById(R.id.ligneClient);

            choisir.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null) {
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION) {
                            if (!CommandesActivity.listeAllClientsFiltre.isEmpty()) {
                                CommandesActivity.currentCommande.setIdClient(CommandesActivity.listeAllClientsFiltre.get(position).getId());
                                CommandesActivity.currentCommande.setNomClient(CommandesActivity.listeAllClientsFiltre.get(position).getNomEntreprise());
                                CommandesActivity.currentCommande.setIdPaysClient(CommandesActivity.listeAllClientsFiltre.get(position).getIdPays());
                                CommandesActivity.currentCommande.setCodePostalClient(CommandesActivity.listeAllClientsFiltre.get(position).getCp());
                                CommandesActivity.nom.setText(CommandesActivity.listeAllClientsFiltre.get(position).getNomEntreprise());
                                try {
                                    //Ici on actualise uniquement le prix supplément si transporteur choisi CHRONO FR
                                    //Récupérer le supplément livraison si il est là
                                    //Uniquement si on dispose du code postal du client et client pays FRANCE
                                    if (CommandesActivity.listeAllSupplementTransporteurChronopostFrance != null && CommandesActivity.currentCommande.getIdPaysClient() == 8 && CommandesActivity.currentCommande.getCodePostalClient() != null) {
                                        //Chercher le supplément
                                        TransporteurChronopostFranceSupplement ts = CommandesActivity.getSupplementTransporteurChronospostFrance(CommandesActivity.currentCommande.getCodePostalClient());
                                        if (ts != null) {
                                            CommandesActivity.currentCommande.setIdTransporteurPrixSupplementLivraison(ts.getId());
                                            CommandesActivity.currentCommande.setPrixSupplementLivraison(ts.getSupplementTransporteur());
                                        }
                                    } else {
                                        CommandesActivity.currentCommande.setIdTransporteurPrixSupplementLivraison(0);
                                        CommandesActivity.currentCommande.setPrixSupplementLivraison(0);
                                    }
                                    CommandesActivity.appliquerPrixLivraison();
                                } catch (Exception e) {
                                    e.printStackTrace();
                                }
                            }
                            CommandesActivity.affichelisteclients = 0;
                            CommandesActivity.barNom.setVisibility(View.VISIBLE);
                            CommandesActivity.barIntituleChamps.setVisibility(View.VISIBLE);
                            CommandesActivity.barIntituleChampsClients.setVisibility(View.GONE);
                            CommandesActivity.recyclerViewClients.setVisibility(View.GONE);
                            CommandesActivity.recyclerView.setVisibility(View.VISIBLE);
                            CommandesActivity.searchBar.setVisibility(View.VISIBLE);
                            CommandesActivity.searchBarProduitCommande.setVisibility(View.VISIBLE);
                            CommandesActivity.searchBarClientCommande.setVisibility(View.GONE);
                            CommandesActivity.infos.setVisibility(View.VISIBLE);
                            CommandesActivity.imprimer.setVisibility(View.VISIBLE);
                            CommandesActivity.choixCommande.setVisibility(View.VISIBLE);
                            CommandesActivity.activerToujoursScanner.setVisibility(View.VISIBLE);
                            CommandesActivity.reloadScanner.setVisibility(View.VISIBLE);
                            CommandesActivity.ajouterRemiseCommande.setVisibility(View.VISIBLE);
                        }
                    }
                }
            });

        }

    }
}